package com.supervision.police.controller;

import com.supervision.common.domain.R;
import com.supervision.police.dto.CaseEvidenceDetailDTO;
import com.supervision.police.service.CaseEvidenceService;
import com.supervision.police.dto.CaseEvidenceDTO;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 案件证据控制器
 */
@Slf4j
@RestController
@Tag(name = "案件证据")
@RequiredArgsConstructor
@RequestMapping("/caseEvidence")
public class CaseEvidenceController {

    private final CaseEvidenceService caseEvidenceService;

    @Operation(summary = "保存案件证据信息")
    @PostMapping("/saveEvidence")
    public R<String> saveEvidence(@RequestBody CaseEvidenceDTO caseEvidenceDTO) {
        String evidenceId = caseEvidenceService.saveEvidence(caseEvidenceDTO);
        return R.ok(evidenceId);
    }

    @Operation(summary = "更新案件证据信息")
    @PostMapping("/updateEvidence")
    public R<String> updateEvidence(@RequestBody CaseEvidenceDTO caseEvidenceDTO) {
        String evidenceId =  caseEvidenceService.updateEvidence(caseEvidenceDTO);
        return R.ok(evidenceId);
    }

    @Operation(summary = "删除案件证据信息")
    @DeleteMapping("/deleteEvidence")
    public R<Boolean> deleteEvidence(String evidenceId) {
        boolean success = caseEvidenceService.deleteEvidence(evidenceId);
        return R.ok(success);
    }


    @GetMapping("/queryEvidenceDetail")
    public R<CaseEvidenceDetailDTO> queryEvidenceDetail(@RequestParam @Parameter(name = "evidenceId",description = "证据id") String evidenceId) {
        CaseEvidenceDetailDTO caseEvidenceDetailDTO = caseEvidenceService.queryEvidenceDetail(evidenceId);
        return R.ok(caseEvidenceDetailDTO);
    }
    @Operation(summary = "查询案件证据信息列表")
    @GetMapping("/list")
    public R<List<CaseEvidenceDetailDTO>> queryEvidenceList(@RequestParam @Parameter(name = "caseId",description = "案件id") String caseId) {
        List<CaseEvidenceDetailDTO> caseEvidenceDetailDTOS = caseEvidenceService.queryEvidenceList(caseId);
        return R.ok(caseEvidenceDetailDTOS);
    }
}
